@@ -9,12 +9,16 @@ config = {
         'monkey': 'bar',
         }
 
+
 def test_load_file():
-    args = _external_load(['twanager', '--load', 'test/test_external_load.py', 'foobar'], global_config)
+    args = _external_load(['twanager', '--load', 'test/test_external_load.py',
+        'foobar'], global_config)
     assert args == ['twanager', 'foobar']
     assert global_config['monkey'] == 'bar'
 
+
 def test_load_module():
-    args = _external_load(['twanager', '--load', 'test.test_external_load', 'foobar'], global_config)
+    args = _external_load(['twanager', '--load', 'test.test_external_load',
+        'foobar'], global_config)
     assert args == ['twanager', 'foobar']
     assert global_config['monkey'] == 'bar'
