@@ -3,7 +3,6 @@
 for plain text.
 """
 
-import urllib
 import simplejson
 
 from base64 import b64encode, b64decode
@@ -15,6 +14,8 @@ from tiddlyweb.serializations import SerializationInterface
 from tiddlyweb.model.policy import Policy
 from tiddlyweb.util import binary_tiddler
 
+from tiddlyweb.fixups import quote, unquote, basestring, unicode
+
 
 class Serialization(SerializationInterface):
     """
@@ -69,12 +70,10 @@ class Serialization(SerializationInterface):
 
         for bag, filter_string in recipe.get_recipe():
             line = ''
-            if not isinstance(bag, basestring):
-                bag = bag.name
             if not get_bag_retriever(self.environ, bag):
                 # If there is a retriever for this bag name then
                 # we want to write its name straight.
-                line += '/bags/%s/tiddlers' % urllib.quote(
+                line += '/bags/%s/tiddlers' % quote(
                         bag.encode('utf-8'), safe='')
             else:
                 line += bag
@@ -168,7 +167,8 @@ class Serialization(SerializationInterface):
                 raise TiddlerFormatError(
                         'reserved key "%s" in fields of tiddler: %s'
                         % (key, tiddler.title))
-            if not key.startswith('server.'):  # XXX: TiddlyWiki legacy remnant?
+            # XXX: TiddlyWiki legacy remnant?
+            if not key.startswith('server.'):
                 value = unicode(tiddler.fields[key])
                 fields.append('%s: %s' % (key, value.replace('\n', '\\n')))
         return fields
@@ -190,7 +190,7 @@ class Serialization(SerializationInterface):
                     setattr(tiddler, field, value)
                 else:
                     tiddler.fields[field] = value.replace('\\n', '\n')
-        except ValueError, exc:
+        except ValueError as exc:
             raise TiddlerFormatError('bad headers in tiddler: %s, %s' %
                     (tiddler.title, exc))
 
@@ -226,8 +226,7 @@ class Serialization(SerializationInterface):
                     filter_string = ''
                 if bag.startswith('/bags/'):
                     bagname = bag.split('/')[2]
-                    bagname = urllib.unquote(bagname.encode('utf-8'))
-                    bagname = bagname.decode('utf-8')
+                    bagname = unquote(bagname)
                 else:
                     bagname = bag
                 recipe_lines.append((bagname, filter_string))
