@@ -26,6 +26,8 @@ from tiddlyweb.web.util import (check_bag_constraint, get_route_value,
 from tiddlyweb.web.sendtiddlers import send_tiddlers
 from tiddlyweb.web.validator import validate_tiddler, InvalidTiddlerError
 
+from tiddlyweb.fixups import basestring, bytes
+
 
 CACHE_CONTROL_FIELD = '_cache-max-age'
 CANONICAL_URI_FIELD = '_canonical_uri'
@@ -127,7 +129,7 @@ def _delete_tiddler(environ, start_response, tiddler):
         check_bag_constraint(environ, bag, 'delete')
 
         store.delete(tiddler)
-    except NoTiddlerError, exc:
+    except NoTiddlerError as exc:
         raise HTTP404('%s not found, %s' % (tiddler.title, exc))
 
     start_response("204 No Content", [])
@@ -161,12 +163,12 @@ def _determine_tiddler(environ, bag_finder, revisions=False):
             store = environ['tiddlyweb.store']
             recipe = store.get(recipe)
             tiddler.recipe = recipe_name
-        except NoRecipeError, exc:
+        except NoRecipeError as exc:
             raise HTTP404('%s not found via recipe, %s' % (tiddler.title, exc))
 
         try:
             bag = bag_finder(recipe, tiddler, environ)
-        except NoBagError, exc:
+        except NoBagError as exc:
             raise HTTP404('%s not found via bag, %s' % (tiddler.title, exc))
 
         bag_name = bag.name
@@ -198,7 +200,7 @@ def _process_request_body(environ, tiddler):
                 serializer.object = tiddler
                 try:
                     serializer.from_string(content.decode('utf-8'))
-                except TiddlerFormatError, exc:
+                except TiddlerFormatError as exc:
                     raise HTTP400('unable to put tiddler: %s' % exc)
             else:
                 raise NoSerializationError()
@@ -208,7 +210,7 @@ def _process_request_body(environ, tiddler):
                 tiddler.text = content.decode('utf-8')
             else:
                 tiddler.text = content
-    except UnicodeDecodeError, exc:
+    except UnicodeDecodeError as exc:
         raise HTTP400('unable to decode tiddler, utf-8 expected: %s', exc)
 
 
@@ -267,17 +269,17 @@ def _put_tiddler(environ, start_response, tiddler):
 
         try:
             check_bag_constraint(environ, bag, 'accept')
-        except (PermissionsError), exc:
+        except (PermissionsError) as exc:
             _validate_tiddler_content(environ, tiddler)
 
         store.put(tiddler)
-    except NoBagError, exc:
+    except NoBagError as exc:
         raise HTTP409("Unable to put tiddler, %s. There is no bag named: "
                 "%s (%s). Create the bag." %
                 (tiddler.title, tiddler.bag, exc))
-    except NoTiddlerError, exc:
+    except NoTiddlerError as exc:
         raise HTTP404('Unable to put tiddler, %s. %s' % (tiddler.title, exc))
-    except TypeError, exc:
+    except TypeError as exc:
         raise HTTP409('Unable to put badly formed tiddler, %s:%s. %s'
                 % (tiddler.bag, tiddler.title, exc))
 
@@ -298,7 +300,7 @@ def _validate_tiddler_content(environ, tiddler):
     """
     try:
         validate_tiddler(tiddler, environ)
-    except InvalidTiddlerError, exc:
+    except InvalidTiddlerError as exc:
         raise HTTP409('Tiddler content is invalid: %s' % exc)
 
 
@@ -368,13 +370,13 @@ def _send_tiddler(environ, start_response, tiddler):
     # this will raise 403 if constraint does not pass
     try:
         check_bag_constraint(environ, bag, 'read')
-    except NoBagError, exc:
+    except NoBagError as exc:
         raise HTTP404('%s not found, no bag %s, %s' %
                 (tiddler.title, tiddler.bag, exc))
 
     try:
         tiddler = store.get(tiddler)
-    except NoTiddlerError, exc:
+    except NoTiddlerError as exc:
         raise HTTP404('%s not found, %s' % (tiddler.title, exc))
 
     # this will raise 304
@@ -404,9 +406,9 @@ def _send_tiddler(environ, start_response, tiddler):
         response.append(last_modified)
     if etag:
         response.append(etag)
-    start_response("200 OK", response)
+    start_response('200 OK', response)
 
-    if isinstance(content, basestring):
+    if isinstance(content, basestring) or isinstance(content, bytes):
         return [content]
     else:
         return content
@@ -428,7 +430,7 @@ def _get_tiddler_content(environ, tiddler):
     # there unless we are requesting a json form
     if (CANONICAL_URI_FIELD in tiddler.fields
             and not CANONICAL_URI_PASS_TYPE in mime_type):
-        raise HTTP302(tiddler.fields[CANONICAL_URI_FIELD].encode('utf-8'))
+        raise HTTP302(tiddler.fields[CANONICAL_URI_FIELD])
 
     if not renderable(tiddler, environ):
         if (serialize_type == default_serialize_type or
@@ -444,7 +446,7 @@ def _get_tiddler_content(environ, tiddler):
     try:
         content = serializer.to_string()
         serialized = True
-    except (TiddlerFormatError, NoSerializationError), exc:
+    except (TiddlerFormatError, NoSerializationError) as exc:
         raise HTTP415(exc)
     return content, mime_type, serialized
 
@@ -479,10 +481,10 @@ def _send_tiddler_revisions(environ, start_response, tiddler):
             tmp_tiddler.revision = revision
             tmp_tiddler.recipe = tiddler.recipe
             tiddlers.add(tmp_tiddler)
-    except NoTiddlerError, exc:
+    except NoTiddlerError as exc:
         # If a tiddler is not present in the store.
         raise HTTP404('tiddler %s not found, %s' % (tiddler.title, exc))
-    except NoBagError, exc:
+    except NoBagError as exc:
         raise HTTP404('tiddler %s not found, bag %s does not exist, %s'
                 % (tiddler.title, tiddler.bag, exc))
     except StoreMethodNotImplemented:
